#
# Copyright (C) 2010 Martin Owens
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Package for supplying default values and useful code for genetic wallpaper generation.
"""
import sys
import os

from fnmatch import fnmatch

__package__ = 'genetic-wallpapers'
__version__ = '1.1'
GLOBAL_FILES = '/usr/share/genetic-wallpapers/'
LOCAL_FILES = os.path.expanduser('~/.config/genetic-wallpapers/')


def get_plots(path):
    """Returns a plot file path if it exists"""
    path = '.'.join(path.split('.')[:-1])+'.plot'
    gfile = get_file(path, 'plots')
    lfile = get_file(path, 'plots', LOCAL_FILES)
    return lfile or gfile

def get_file(path, category='', location=GLOBAL_FILES):
    """Return the filename of a resource in a location."""
    filename = os.path.basename(path)
    pfile = os.path.join(location, 'plots', filename)
    return os.path.exists(pfile) and pfile or None

def listfiles(*dirs):
    """Return a list of files matching the given pattern"""
    dir, pattern = os.path.split(os.path.join(*dirs))
    return [os.path.join(dir, filename)
            for filename in os.listdir(os.path.abspath(dir))
                    if filename[0] != '.' and fnmatch(filename, pattern)]


