#
# Copyright (C) 2010 Martin Owens
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Interacting with gnome backgrounds.
"""
import os
import sys
from xml.dom.minidom import parse


def getText(node):
    nodelist = node.childNodes
    rc = []
    for node in nodelist:
        if node.nodeType == node.TEXT_NODE:
            rc.append(node.data)
    return ''.join(rc)


def get_gnome_wallpaper():
    """Return the currently chosen wallpaper."""
    # We would use gconf directly to get this data, but that's impossible
    # Because gnome developers forgot to make sure user cron could
    # access gconf (which it can't atm) so now this code is the result.
    # *roll eyes*
    conf = os.path.expanduser('~/.gconf/desktop/gnome/background/%gconf.xml')
    if not os.path.exists(conf):
        return None
    xmldom = parse(conf)
    for element in xmldom.getElementsByTagName('stringvalue'):
        if element.parentNode.getAttribute('name') == 'picture_filename':
            return getText(element)
    return None


class GnomeBackgrounds(object):
    """Control the gnome backgrounds configuration."""
    settings = os.path.expanduser('~/.gnome2/backgrounds.xml')

    def __init__(self):
        self.xmldom = parse(self.settings)

    def remove(self, filename):
        """Remove a gnome background from the config."""
        wpt = self.wallpaperTag()
        for wp in wpt.childNodes:
            meta = self.decodeWP(wp)
            if wp.nodeType == 1 and unicode(meta['filename']) == filename:
                wpt.removeChild(wp)

    def add(self, filename, wp):
        """Adds a new background image file to the backgrounds.xml file."""
        wp['filename'] = unicode(filename)
        for ewp in self.getList():
            if unicode(ewp) == wp['filename']:
                print "Already added %s, ignore settings for now." % wp['filename']
                return
        wpt = self.wallpaperTag()
        wpt.appendChild(self.encodeWP(wp, self.xmldom))

    def save(self):
        """Save the backgrounds.xml file."""
        fh = open(self.settings, 'w')
        fh.write(self.xmldom.toxml(encoding="utf-8"))
        fh.close()

    def wallpaperTag(self):
        """Return specific wallpaper tag from wallpapers"""
        for child in self.xmldom.childNodes:
            if child.nodeType == 1 and child.tagName == 'wallpapers':
                return child
        return None

    def getList(self):
        """Return a list of gnome backgrounds"""
        for wp in self.wallpaperTag().childNodes:
            if wp.nodeType == 1 and wp.tagName == 'wallpaper':
                if wp.attributes.has_key('deleted') and wp.attributes['deleted']=='true':
                    continue
                item = self.decodeWP(wp)
                yield item['filename']

    def decodeWP(self, node):
        """Basic XML helper method for getting text values"""
        results = {}
        for value in node.childNodes:
            if value.nodeType==1:
                ndata = ''
                for val in value.childNodes:
                    if val.nodeType==3: # TEXT_NODE
                        ndata += val.data
                results[value.tagName] = ndata
        return results

    def encodeWP(self, wp, doc):
        """Basic XML helper method for setting text values"""
        node = doc.createElement('wallpaper')
        node.attributes['deleted'] = 'false'
        for key in wp.keys():
            tag = doc.createElement(key)
            tag.appendChild(doc.createTextNode(unicode(wp[key])))
            node.appendChild(tag)
        return node

