#!/usr/bin/env python
#
# Copyright (C) 2010 Martin Owens
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

from distutils.core import setup
import os, platform

from GeneticWallpapers import listfiles, __version__, __package__

# remove MANIFEST. distutils doesn't properly update it when the contents of directories change.
if os.path.exists('MANIFEST'): os.remove('MANIFEST')

if platform.system() == 'FreeBSD':
        man_dir = 'man'
else:
        man_dir = 'share/man'

setup(
        name             = str(__package__),
        version          = str(__version__),
        description      = 'Provide scripts for genetic svg wallpapers using genetic plotting and randomness',
        long_description = "Uses plotting devices to control the flow of randomisation in shapes for a given screen background, looks fancy.",
        author           = 'Martin Owens',
        author_email     = 'doctormo@ubuntu.com',
        url              = 'https://code.launchpad.net/~doctormo/',
        platforms        = 'linux',
        license          = 'GPLv3',
        packages         = [ "GeneticWallpapers" ],
        scripts          = [ 'wallgen-login-check', 'wallgen-user-check', 'wallgen-nudge', 'wallgen-nudge-in-use', 'wallgen-plot' ],
        data_files       = [
            ( '/etc/xdg/autostart/', [ 'wallgen-login.desktop' ] ),
            ( os.path.join(man_dir, 'man1'), listfiles( 'doc', '*.1' ) ),
            ( '/usr/share/genetic-wallpapers/', [ 'wallpaper-refresh.update-notifier' ] ),
        ],
    )

